@@ -272,7 +272,7 @@ class ToolInfo():
             self.path = response
             self.tool_found = True
         except:
-            raise ToolNotFoundError("Could not find Tool", self)
+            raise ToolInfoNotFoundError("Could not find Tool", self)
 
 
     def get_version(self):
@@ -293,7 +293,15 @@ class ToolInfo():
 
 def get_snakemake_info():
     return ToolInfo("snakemake", ["snakemake", "--version"]) 
-    
+
+def has_mamba():
+    ret = False
+    try:
+        ToolInfo("mamba", ["mamba", "-V"])
+        ret = True
+    except ToolInfoNotFoundError:
+        pass
+    return ret
 
 def main(snakemake=None,cmd=None):
     supress_error = False
@@ -776,7 +784,8 @@ def check_pangolin(prefix, name):
                 """eval "$(conda shell.bash hook)"; {call}""".format(
                     call=" ".join(call)),
                 shell=True,
-                stderr=subprocess.STDOUT, 
+                stderr=subprocess.STDOUT,
+                executable="/bin/bash",
                 universal_newlines=True)
         is_conda = True
         env_list_lines = env_list.split("\n")
@@ -805,9 +814,10 @@ def prefix_augment(prefix):
 def setup_log_dir(args):
     outdir = args.output
     if args.log is None:
-        log_prefix = os.path.join(outdir, "ncov-minipipe-logs") 
+        log_prefix = os.path.join(outdir, "results", 
+                                  "intermediate_data", "00_logs", "_main_log") 
         mkdir_if_not_exists(log_prefix) 
-        logfile = "ncov-minipipe" 
+        logfile = "covpipe" 
         file_prefix = os.path.join(log_prefix,logfile)
         if os.path.isfile(file_prefix +".log"):
             logfile= "{_file}_{timestamp}.log".format(
@@ -1645,13 +1655,16 @@ def real_snake_call(args, unknown_args, conf, samp_conf, rerun_list):
     if rerun_list:
         rerun_list = ["-R"] + rerun_list
     conda_prefix = []
+    conda_frontend = ["--conda-frontend", "mamba" if has_mamba() else "conda"] 
     if args.conda_prefix is not None:
         conda_prefix = ["-d", args.output,
                         '--conda-prefix', args.conda_prefix]
     snake_cmd=(BASIC_SNAKE_CALL + [ "--cores", str(args.cpus) ] +  ["--configfile", conf] +
                rerun_list + unknown_args + ["--use-conda"] + conda_prefix)
+    snake_cmd.extend(conda_frontend)
     short_snake_cmd =(BASIC_SNAKE_CALL + [ "--cores", str(args.cpus) ] +  ["--configfile", conf] +
                       unknown_args + ["--use-conda"] + conda_prefix)
+    short_snake_cmd.extend(conda_frontend)
     if unknown_args:
         logger.info("Arguments not known are being appended to the snakemake call.\n"
                     "Please refer to the snakemake help for issues encountered.\n"
@@ -1729,11 +1742,11 @@ def handle_snakemake_syntax_error(string, blame):
         if blame and match:
             match=match.groupdict()
             lnum = int(match["line"])
-            if lnum < 19:
-                bounds = "1,20"
-            else:
-                bounds = "{start},{end}".format(start=lnum-10,
-                                                end=lnum+10)
+            max_lnum = lnum+10
+            with open(match["file"], "r") as fh:
+                max_lnum = len(fh.readlines())
+            bounds = "{start},{end}".format(start=max(lnum-10,1),
+                                            end=min(lnum+10, max_lnum))
             old_cwd = os.getcwd()
             try:
                 os.chdir(SOURCE_DIR)
